@@ -3,17 +3,18 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import Coroutine
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import zigpy.exceptions
 import zigpy.types as t
+import zigpy.zcl
 from zigpy.zcl.clusters import general
 from zigpy.zcl.foundation import Status
 
 from homeassistant.core import callback
 from homeassistant.helpers.event import async_call_later
 
-from .. import registries, typing as zha_typing
+from .. import registries
 from ..const import (
     REPORT_CONFIG_ASAP,
     REPORT_CONFIG_BATTERY_SAVE,
@@ -26,7 +27,10 @@ from ..const import (
     SIGNAL_SET_LEVEL,
     SIGNAL_UPDATE_DEVICE,
 )
-from .base import ClientChannel, ZigbeeChannel, parse_and_log_command
+from .base import AttrReportConfig, ClientChannel, ZigbeeChannel, parse_and_log_command
+
+if TYPE_CHECKING:
+    from . import ChannelPool
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Alarms.cluster_id)
@@ -38,7 +42,9 @@ class Alarms(ZigbeeChannel):
 class AnalogInput(ZigbeeChannel):
     """Analog Input channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.BINDABLE_CLUSTERS.register(general.AnalogOutput.cluster_id)
@@ -46,7 +52,9 @@ class AnalogInput(ZigbeeChannel):
 class AnalogOutput(ZigbeeChannel):
     """Analog Output channel."""
 
-    REPORT_CONFIG = ({"attr": "present_value", "config": REPORT_CONFIG_DEFAULT},)
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
     ZCL_INIT_ATTRS = {
         "min_present_value": True,
         "max_present_value": True,
@@ -115,7 +123,9 @@ class AnalogOutput(ZigbeeChannel):
 class AnalogValue(ZigbeeChannel):
     """Analog Value channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.ApplianceControl.cluster_id)
@@ -147,21 +157,27 @@ class BasicChannel(ZigbeeChannel):
 class BinaryInput(ZigbeeChannel):
     """Binary Input channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.BinaryOutput.cluster_id)
 class BinaryOutput(ZigbeeChannel):
     """Binary Output channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.BinaryValue.cluster_id)
 class BinaryValue(ZigbeeChannel):
     """Binary Value channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Commissioning.cluster_id)
@@ -173,12 +189,12 @@ class Commissioning(ZigbeeChannel):
 class DeviceTemperature(ZigbeeChannel):
     """Device Temperature channel."""
 
-    REPORT_CONFIG = [
+    REPORT_CONFIG = (
         {
             "attr": "current_temperature",
             "config": (REPORT_CONFIG_MIN_INT, REPORT_CONFIG_MAX_INT, 50),
-        }
-    ]
+        },
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.GreenPowerProxy.cluster_id)
@@ -221,7 +237,7 @@ class LevelControlChannel(ZigbeeChannel):
     """Channel for the LevelControl Zigbee cluster."""
 
     CURRENT_LEVEL = 0
-    REPORT_CONFIG = ({"attr": "current_level", "config": REPORT_CONFIG_ASAP},)
+    REPORT_CONFIG = (AttrReportConfig(attr="current_level", config=REPORT_CONFIG_ASAP),)
     ZCL_INIT_ATTRS = {
         "on_off_transition_time": True,
         "on_level": True,
@@ -271,21 +287,27 @@ class LevelControlChannel(ZigbeeChannel):
 class MultistateInput(ZigbeeChannel):
     """Multistate Input channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.MultistateOutput.cluster_id)
 class MultistateOutput(ZigbeeChannel):
     """Multistate Output channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.MultistateValue.cluster_id)
 class MultistateValue(ZigbeeChannel):
     """Multistate Value channel."""
 
-    REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
+    REPORT_CONFIG = (
+        AttrReportConfig(attr="present_value", config=REPORT_CONFIG_DEFAULT),
+    )
 
 
 @registries.CLIENT_CHANNELS_REGISTRY.register(general.OnOff.cluster_id)
@@ -299,14 +321,12 @@ class OnOffChannel(ZigbeeChannel):
     """Channel for the OnOff Zigbee cluster."""
 
     ON_OFF = 0
-    REPORT_CONFIG = ({"attr": "on_off", "config": REPORT_CONFIG_IMMEDIATE},)
+    REPORT_CONFIG = (AttrReportConfig(attr="on_off", config=REPORT_CONFIG_IMMEDIATE),)
     ZCL_INIT_ATTRS = {
         "start_up_on_off": True,
     }
 
-    def __init__(
-        self, cluster: zha_typing.ZigpyClusterType, ch_pool: zha_typing.ChannelPoolType
-    ) -> None:
+    def __init__(self, cluster: zigpy.zcl.Cluster, ch_pool: ChannelPool) -> None:
         """Initialize OnOffChannel."""
         super().__init__(cluster, ch_pool)
         self._off_listener = None
@@ -388,9 +408,9 @@ class OnOffConfiguration(ZigbeeChannel):
     """OnOff Configuration channel."""
 
 
-@registries.CLIENT_CHANNELS_REGISTRY.register(general.Ota.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Ota.cluster_id)
-class Ota(ZigbeeChannel):
+@registries.CLIENT_CHANNELS_REGISTRY.register(general.Ota.cluster_id)
+class Ota(ClientChannel):
     """OTA Channel."""
 
     BIND: bool = False
@@ -407,6 +427,7 @@ class Ota(ZigbeeChannel):
 
         signal_id = self._ch_pool.unique_id.split("-")[0]
         if cmd_name == "query_next_image":
+            assert args
             self.async_send_signal(SIGNAL_UPDATE_DEVICE.format(signal_id), args[3])
 
 
@@ -470,8 +491,10 @@ class PowerConfigurationChannel(ZigbeeChannel):
     """Channel for the zigbee power configuration cluster."""
 
     REPORT_CONFIG = (
-        {"attr": "battery_voltage", "config": REPORT_CONFIG_BATTERY_SAVE},
-        {"attr": "battery_percentage_remaining", "config": REPORT_CONFIG_BATTERY_SAVE},
+        AttrReportConfig(attr="battery_voltage", config=REPORT_CONFIG_BATTERY_SAVE),
+        AttrReportConfig(
+            attr="battery_percentage_remaining", config=REPORT_CONFIG_BATTERY_SAVE
+        ),
     )
 
     def async_initialize_channel_specific(self, from_cache: bool) -> Coroutine:
